/*----------------------------------------------------------------------------
 HMG Source Code

 Copyright 2002-2010 Roberto Lopez <mail.box.hmg@gmail.com>
 http://sites.google.com/site/hmgweb/

 This program is free software; you can redistribute it and/or modify it under 
 the terms of the GNU General Public License as published by the Free Software 
 Foundation; either version 2 of the License, or (at your option) any later 
 version. 

 This program is distributed in the hope that it will be useful, but WITHOUT 
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with 
 this software; see the file COPYING. If not, write to the Free Software 
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA (or 
 visit the web site http://www.gnu.org/).

 As a special exception, you have permission for additional uses of the text 
 contained in this release of HMG.

 The exception is that, if you link the HMG library with other 
 files to produce an executable, this does not by itself cause the resulting 
 executable to be covered by the GNU General Public License.
 Your use of that executable is in no way restricted on account of linking the 
 HMG library code into it.

---------------------------------------------------------------------------*/

#include "hbclass.ch"
#include "common.ch"

#define WORLD   '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'

*..............................................................................*
* Class Frame .................................................................*
*..............................................................................*

CLASS LABEL FROM CONTROL

	* Internal Data

	DATA lAutoSize		INIT	.F.
	DATA cValue		INIT	''
	DATA aBackColor	INIT	Nil
	DATA aFontColor	INIT	Nil
	* Properties 

	METHOD AutoSize	SETGET
	METHOD Value		SETGET
	METHOD BackColor	SETGET
	METHOD FontColor	SETGET
	* Methods

	METHOD Create()

ENDCLASS

*..............................................................................*
* Properties ..................................................................*
*..............................................................................*

METHOD AutoSize ( lValue ) CLASS LABEL

RETURN Nil

*----------------------------------------------------------------------------------*

METHOD Value ( cValue ) CLASS LABEL

	If ::lCreated

	        If Pcount() == 0
	
			RETURN ::oQTObject:Text()

		ElseIf Pcount() == 1 

			::oQTObject:SetText(cValue)

		EndIf

	Else

	        If Pcount() == 0
	
			RETURN ::cValue

		ElseIf Pcount() == 1 

			::cValue := cValue

		EndIf

	EndIf

RETURN Nil

RETURN Nil

*..............................................................................*
* Methods .....................................................................*
*..............................................................................*

METHOD Create() CLASS LABEL
	local nW, nH, nFontSize
	local cStyleSheet := ''

	cTestString += "create;"
	::oQTObject := QLabel():new( ::oParent:oQTObject )

	::oQTObject:SetText( ::cValue )

	::oQTObject:move( ::nCol , ::nRow )

	cTestString += "move;"

	if ValType(::nWidth) == 'U'
		// set default width of label
		nW := 120
	else
		nW := ::nWidth
	endif
	
	if ValType(::nHeight) == 'U'
		nH := 24
	else
		nH := ::nHeight
	endif
	
	::oQTObject:resize( nW , nH)
	cTestString += "resize;"
	
	*if ValType(::nWidth) != 'U' .and. ValType(::nHeight) != 'U'
	*	::oQTObject:resize( ::nWidth , ::nHeight )
	*endif

	if ValType(::nFontSize) == 'U'
		nFontSize := 9
	else
		nFontSize := ::nFontSize
	endif
	
	if ValType(::aFontColor) == 'U'
		xForeColor := '#00ff00;'
	else
		xForeColor := '#'+NTOC(::aFontColor[1],16,2,"0")+NTOC(::aFontColor[2],16,2,"0")+NTOC(::aFontColor[3],16,2,"0")+';'
	endif

	cStyleSheet += 'color:'+xForeColor + ';'

	if ValType(::aBackColor) == 'A'
		cStyleSheet += 'background-color:#'+;
			NTOC(::aBackColor[1],16,2,"0")+NTOC(::aBackColor[2],16,2,"0")+NTOC(::aBackColor[3],16,2,"0")+';'
	endif

	if !empty(cStyleSheet)
		::oQTObject:setStyleSheet(cStyleSheet)
	endif
	
	::oFont := QFont():New( ::cFontName )
	::oFont:SetPointSize( nFontSize )
	::oFont:SetBold( ::lBold )
	::oFont:SetItalic( ::lItalic )
	::oFont:SetUnderline( ::lUnderline )
	::oFont:SetStrikeOut( ::lStrikeout )

	
	::oQTObject:SetFont( ::oFont )

	::oQTObject:show()

	::lCreated := .T.

	::oParent:AddData ( ::cName , Self )

RETURN Self

METHOD FontColor( aValue ) CLASS LABEL
	local cStyleSheet := ""
	
    If ::lCreated

		If Pcount() == 0

			Return ::aFontColor

		ElseIf Pcount() == 1 

			if ValType(aValue) == 'A'
				cStyleSheet := 'color:#'+NTOC(aValue[1],16,2,"0")+NTOC(aValue[2],16,2,"0")+NTOC(aValue[3],16,2,"0")+';'
			endif
			if !empty(cStyleSheet)
				::oQTObject:setStyleSheet(cStyleSheet)
			endif

		EndIf

	Else

		If	Pcount() == 0

			Return ::aFontColor

		ElseIf	Pcount() == 1
			::aFontColor := aValue
		EndIf

	EndIf

RETURN Nil

METHOD BackColor( aValue ) CLASS LABEL
	local cStyleSheet := ""

    If ::lCreated
	    If Pcount() == 0

			Return ::aBackColor

		ElseIf Pcount() == 1 

			if ValType(aValue) == 'A'
				cStyleSheet := 'background-color:#'+NTOC(aValue[1],16,2,"0")+NTOC(aValue[2],16,2,"0")+NTOC(aValue[3],16,2,"0")+';'
			endif
			if !empty(cStyleSheet)
				::oQTObject:setStyleSheet(cStyleSheet)			
			endif

		EndIf

	Else

		If	Pcount() == 0

			Return ::aBackColor

		ElseIf	Pcount() == 1
			::aBackColor := aValue
		EndIf

	EndIf

RETURN Nil

*---------------------------------------
*---------------------------------------
*---------------------------------------
FUNCTION NTOC( xNum, nBase, nLenght, cPad )
LOCAL cNum

Default cPad to " "
Default nBase to 10

IF ISCHARACTER( xNum )
   xNum := UPPER( ALLTRIM( xNum ) )
   xNum := CTON( xNum, 16 )
ENDIF
IF nBase > 36 .OR. nBase < 2
   RETURN ""
ENDIF

if xNum < 0
  xNum += 4294967296
endif
cNum := B10TOBN( xNum, @nBase )

IF ISNUMBER( nLenght )
   IF LEN(cNum) > nLenght
      cNum := REPLICATE( "*", nLenght )
   ELSEIF ISCHARACTER( cPad ) .AND. LEN( cNum ) < nLenght
      cNum := REPLICATE( cPad, nLenght - LEN( cNum ) ) + cNum
   ENDIF
ENDIF

RETURN cNum
FUNCTION CTON( xNum, nBase, lMode )
LOCAL i, nNum := 0, nPos

Default lMode TO .F.
Default nBase TO 10

IF ISCHARACTER(xNum) .and. nBase >= 2 .and. nBase <= 36

   xNum := UPPER( ALLTRIM( xNum) )

   FOR i := 1 TO LEN( xNum )
      nPos := AT( SUBSTR( xNum, i, 1 ), WORLD )
      IF nPos == 0 .or. nPos > nBase
         EXIT
      ELSE
         nNum := nNum * nBase + ( nPos - 1 )
      ENDIF
   NEXT

   IF lMode
      IF nNum > 32767
         nNum := nNum - 65536
      ENDIF
   ENDIF

ENDIF

RETURN nNum


STATIC FUNCTION B10TOBN( nNum, nBase )
LOCAL nInt
IF nNum > 0

   nInt := INT( nNum / nBase)
   RETURN iif(nInt==0, "", B10TOBN( nInt, @nBase )) +;
          SUBSTR( WORLD, ( nNum % nBase ) + 1, 1 )

ELSEIF nNum == 0
   RETURN "0"
ENDIF
RETURN ""
